"""YamlInfo Main Module"""
# coding=utf-8
import yaml
import logging


class YamlInfo:
    """Parse Yaml config file."""

    yaml_info_dict = {}

    def __init__(self, yaml_config_file, option, input_file) -> None:
        """Load yaml information and parse args info."""
        with open(yaml_config_file, 'rb') as input_config_file_object:
            yaml_info_strings = input_config_file_object.read()
        self.yaml_info_dict = yaml.load(yaml_info_strings)
        if option == "projectinfo":
            if input_file == "LICENSE":
                with open("LICENSE") as license_file:
                    license_strings = license_file.read()
                self.yaml_info_dict["license"] = license_strings.strip('\n')
            project_info_data = self.yaml_info_dict["info"]
            project_version_data = self.yaml_info_dict["version"]
            __version__ = "%(major)s.%(minor)s.%(revision)s" % project_version_data
            logging.info("Starting " + self.yaml_info_dict["info"]["name"] + " v" + __version__)
            for items in project_info_data:
                logging.info(str(items) + ":" + str(project_info_data[items]))

    def get(self) -> dict:
        """Return parsed project config file as a dict."""
        return self.yaml_info_dict



"""YamlInfo Install Script"""
# coding=utf-8
from setuptools import setup, find_packages
from pkg_resources import require, DistributionNotFound
try:
    require('PyYAML')
    required='PyYAML'
except DistributionNotFound:
    required = 'PyYAML'

from yaml_info.yamlinfo import YamlInfo



project_data = YamlInfo("projectinfo.yml", "projectinfo", "LICENSE").get()
project_info_data = project_data["info"]
project_version_data = project_data["version"]
__version__ = "%(major)s.%(minor)s.%(revision)s.%(release)s" % project_version_data

setup(
    name=project_data["info"]["name"],
    version=__version__,
    include_package_data=True,
    install_requires=["PyYAML"],
    packages=find_packages(exclude=["docs", "tests*"]),
    url="https://github.com/AUCR/YamlInfo",
    license=project_data["info"]["license"],
    author=project_data["info"]["authors"],
    author_email=project_data["info"]["authors_email"],
    description=project_data["info"]["description"],
    classifiers=project_data["info"]["classifiers"],
)
